@@ -26,11 +26,13 @@
 #define _GMIC_QT_FILTERPARAMSWIDGET_H_
 
 #include <QGroupBox>
+#include <QList>
 #include <QModelIndex>
 #include <QPushButton>
 #include <QStringList>
 #include <QVector>
 #include <QWidget>
+#include "KeypointList.h"
 class AbstractParameter;
 class QLabel;
 
@@ -38,18 +40,29 @@ class FilterParametersWidget : public QWidget {
   Q_OBJECT
 
 public:
-  FilterParametersWidget(QWidget * parent = 0);
-  bool build(const QString & name, const QString & hash, const QString & parameters, const QList<QString> & values);
-  void setNoFilter();
+  FilterParametersWidget(QWidget * parent = nullptr);
+  bool build(const QString & name, const QString & hash, const QString & parameters, const QList<QString> & values, const QList<int> & visibilityStates);
+  void setNoFilter(const QString & message = QString::null);
   virtual ~FilterParametersWidget();
   const QString & valueString() const;
   QStringList valueStringList() const;
   void setValues(const QStringList &, bool notify);
+  void setVisibilityStates(const QList<int> & states);
+  QList<int> visibilityStates();
+  QList<int> defaultVisibilityStates();
+
+  void applyDefaultVisibilityStates();
   void reset(bool notify);
   QString filterName() const;
   int actualParametersCount() const;
   QString filterHash() const;
-  void clearButtonParameters() const;
+  void clearButtonParameters();
+  KeypointList keypoints() const;
+  void setKeypoints(KeypointList list, bool notify);
+  bool hasKeypoints() const;
+  const QString & quotedParameters() const;
+
+  static QString flattenParameterList(const QList<QString> & list, const QString & quoted);
 
 public slots:
   void updateValueString(bool notify = true);
@@ -66,6 +79,8 @@ protected:
   QWidget * _paddingWidget;
   QString _filterName;
   QString _filterHash;
+  bool _hasKeypoints;
+  QString _quotedParameters;
 };
 
 #endif // _GMIC_QT_FILTERPARAMSWIDGET_H_
