@@ -32,11 +32,9 @@ class QLabel;
 class LinkParameter : public AbstractParameter {
   Q_OBJECT
 public:
-  LinkParameter(QObject * parent = 0);
+  LinkParameter(QObject * parent = nullptr);
   ~LinkParameter();
-  void addTo(QWidget *, int row) override;
-  void addToKeypointList(KeypointList &) const override;
-  void extractPositionFromKeypointList(KeypointList &) override;
+  bool addTo(QWidget *, int row) override;
   QString textValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
