@@ -41,9 +41,9 @@ class QPushButton;
 class PointParameter : public AbstractParameter {
   Q_OBJECT
 public:
-  PointParameter(QObject * parent = 0);
+  PointParameter(QObject * parent = nullptr);
   ~PointParameter();
-  void addTo(QWidget *, int row) override;
+  bool addTo(QWidget *, int row) override;
   void addToKeypointList(KeypointList &) const override;
   void extractPositionFromKeypointList(KeypointList &) override;
   QString textValue() const override;
@@ -54,6 +54,8 @@ public:
 
   static void resetDefaultColorIndex();
 
+  void setVisibilityState(AbstractParameter::VisibilityState state) override;
+
 public slots:
   void enableNotifications(bool);
 
@@ -66,6 +68,7 @@ private:
   void connectSpinboxes();
   void disconnectSpinboxes();
   void pickColorFromDefaultColormap();
+  void updateView();
   QString _name;
   QPointF _defaultPosition;
   bool _defaultRemovedStatus;
@@ -74,6 +77,7 @@ private:
   bool _removable;
   bool _burst;
   int _radius;
+  bool _keepOpacityWhenSelected;
 
   QLabel * _label;
   QLabel * _colorLabel;
